@@ -290,8 +290,9 @@ private:
 // 判断ScreenScaleFactor的值是否应该应用于所有屏幕
 static bool isGenericScreenScaleFactors(const QByteArray &value)
 {
-    if (value.contains('=') || value.contains(';')){
-        return false;
+    for (char ch : value) {
+        if (ch == '=' || ch == ';')
+            return false;
     }
 
     return true;
@@ -604,6 +605,8 @@ QVariant QDeepinTheme::themeHint(QPlatformTheme::ThemeHint hint) const
         return QVariant(QGenericUnixTheme::xdgIconThemePaths() << QDir::homePath() + "/.local/share/icons");
     case UseFullScreenForPopupMenu:
         return true;
+    case ShowShortcutsInContextMenus:
+        return false;
     default:
         break;
     }
