@@ -769,11 +769,10 @@ QSize Style::sizeFromContents(QStyle::ContentsType type, const QStyleOption *opt
             }
 
             int maxpmw = menuItem->maxIconWidth;
+            int tabSpacing = 20;
             if (menuItem->text.contains(QLatin1Char('\t'))) {
-                if (!hideShortcutText){
-                    int tabSpacing = 20;
+                if (!hideShortcutText)
                     w += tabSpacing;
-                }
             } else {
                 if (menuItem->menuItemType == QStyleOptionMenuItem::SubMenu) {
                     w += 2 * Menu_ArrowHMargin;
